Name: x11-driver-input-synaptics
Version: 1.9.2
Release: %mkrel 1
Summary: X.org input driver for Synaptics touchpad devices
Group: System/X11
URL: https://xorg.freedesktop.org
Source0: https://xorg.freedesktop.org/releases/individual/driver/xf86-input-synaptics-%{version}.tar.xz
Source3:        70-synaptics.conf
Source4:        70-touchpad-quirks.rules
# Fedora patches:
# Mageia patches:
Patch11:	0001-Always-enable-tapping-and-vertical-edge-scroll.patch
Patch12:	0002-When-appling-changes-via-property-mode-apply-to-all.patch

License: MIT

BuildRequires: pkgconfig(libevdev)
BuildRequires: x11-proto-devel
BuildRequires: pkgconfig(xorg-server) >= 1.9.0
BuildRequires: x11-util-macros >= 1.3.0
BuildRequires: pkgconfig(xi)
BuildRequires: pkgconfig(xtst)
BuildRequires: pkgconfig(mtdev)
Provides: synaptics = %{version}-%{release}
Obsoletes: synaptics < %{version}-%{release}

Requires: x11-server-common %(xserver-sdk-abi-requires xinput)

%description
This is the Synaptics touchpad driver for the X.Org X server. The following
touchpad models are supported:
* Synaptics
* appletouch (Post February 2005 and October 2005 Apple Aluminium Powerbooks)
* Elantech (EeePC)
* bcm5974 (Macbook Air (Jan 2008), Macbook Pro Penryn (Feb 2008), iPhone
  (2007), iPod Touch (2008)

Note that support for appletouch, elantech and bcm5974 requires the respective
kernel module.
A touchpad by default operates in compatibility mode by emulating a standard
mouse. However, by using a dedicated driver, more advanced features of the
touchpad become available.

Features:

    * Movement with adjustable, non-linear acceleration and speed.
    * Button events through short touching of the touchpad ("tapping").
    * Double-Button events through double short touching of the touchpad.
    * Dragging through short touching and holding down the finger on the
      touchpad.
    * Middle and right button events on the upper and lower corner of the
      touchpad.
    * Vertical scrolling (button four and five events) through moving the
      finger on the right side of the touchpad.
    * The up/down button sends button four/five events.
    * Horizontal scrolling (button six and seven events) through moving the
      finger on the lower side of the touchpad.
    * The multi-buttons send button four/five events, and six/seven events for
      horizontal scrolling.
    * Adjustable finger detection.
      Multifinger taps: two finger for middle button and three finger for
      right button events. (Needs hardware support. Not all models implement
      this feature.)
    * Run-time configuration using shared memory. This means you can change
      parameter settings without restarting the X server.

%package devel
Summary:        Development files for programming with the xorg synaptics driver
Group:          Development/C

%description devel
Development files for programming with the xorg synaptics driver


%prep
%setup -q -n xf86-input-synaptics-%{version}
%autopatch -p1

%build
autoreconf -v --install --force || exit 1
%configure --with-udev-rules-dir=%{_udevrulesdir}
%make_build

%install
%make_install

# FIXME: Remove all libtool archives (*.la) from modules directory.  This
# should be fixed in upstream Makefile.am or whatever.
find $RPM_BUILD_ROOT -regex ".*\.la$" | xargs rm -f --

# Remove upstream synaptics.conf as we've several special fixes in ours
rm $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d/70-synaptics.conf

install -d $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d/70-synaptics.conf

install -d $RPM_BUILD_ROOT%{_udevrulesdir}
install -m 0644 %{SOURCE4} $RPM_BUILD_ROOT%{_udevrulesdir}/70-touchpad-quirks.rules

%files
%doc README.md
%license COPYING
%{_datadir}/X11/xorg.conf.d/70-synaptics.conf
%{_libdir}/xorg/modules/input/synaptics_drv.so
%{_bindir}/synclient
%{_bindir}/syndaemon
%{_mandir}/man4/synaptics.4*
%{_mandir}/man1/synclient.1*
%{_mandir}/man1/syndaemon.1*
%{_udevrulesdir}/70-touchpad-quirks.rules

%files devel
%license COPYING
%{_libdir}/pkgconfig/xorg-synaptics.pc
%{_includedir}/xorg/synaptics-properties.h




%changelog
* Tue Jul 12 2022 tv <tv> 1.9.2-1.mga9
+ Revision: 1868600
- 1.9.2

* Thu Mar 31 2022 umeabot <umeabot> 1.9.1-4.mga9
+ Revision: 1837594
- Mageia 9 Mass Rebuild
+ danf <danf>
- Switch URLs from http: to https:

* Fri Feb 14 2020 umeabot <umeabot> 1.9.1-3.mga8
+ Revision: 1518466
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.9.1-2.mga7
+ Revision: 1301741
- Mageia 7 Mass Rebuild

* Tue May 29 2018 tv <tv> 1.9.1-1.mga7
+ Revision: 1232923
- new release
- Ship the synaptics file as 70-synaptics.conf to match upstream
  (and sort above libinput)

* Fri Mar 09 2018 tv <tv> 1.9.0-3.mga7
+ Revision: 1207700
- rebuild for xserver 1.20 RC1

* Fri Nov 18 2016 tv <tv> 1.9.0-2.mga6
+ Revision: 1068173
- better description
- package license
- remove .la file
- use std macros
- remove upstream synaptics.conf as we've several special fixes in ours
- new release

* Thu Nov 17 2016 tv <tv> 1.8.99.1-3.mga6
+ Revision: 1067652
- rebuild for xserver 1.19

* Sat Jul 23 2016 tmb <tmb> 1.8.99.1-2.mga6
+ Revision: 1043345
- rebuild for xorg-server 1.18.4

* Mon May 02 2016 tv <tv> 1.8.99.1-1.mga6
+ Revision: 1008510
- adjust file list
- 1.9 RC1

* Mon Jan 18 2016 neoclust <neoclust> 1.8.3-4.mga6
+ Revision: 925470
- Rebuild to fix requires on ARM

* Wed Nov 11 2015 tv <tv> 1.8.3-3.mga6
+ Revision: 902261
- submit to core/release

* Tue Nov 10 2015 tv <tv> 1.8.3-2.mga6
+ Revision: 901418
- rebuild for new xserver

* Mon Nov 02 2015 tv <tv> 1.8.3-1.mga6
+ Revision: 897343
- new release

* Sun Jun 21 2015 tv <tv> 1.8.2-1.mga6
+ Revision: 837433
- new release

* Sat Jun 20 2015 tv <tv> 1.8.1-5.mga6
+ Revision: 835936
- rebuild for xserver 1.17

* Fri Feb 27 2015 tv <tv> 1.8.1-4.mga5
+ Revision: 817196
- add quirks for Acer laptops (mga#15361)

* Thu Feb 26 2015 tv <tv> 1.8.1-3.mga5
+ Revision: 817027
- add quirks & fixes from FC

* Wed Oct 15 2014 umeabot <umeabot> 1.8.1-2.mga5
+ Revision: 750716
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 doktor5000 <doktor5000> 1.8.1-1.mga5
+ Revision: 733690
- new version 1.8.1
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Mon Jun 09 2014 tv <tv> 1.8.0-4.mga5
+ Revision: 634960
- submit to core/release
- HAL is dead

* Fri Jun 06 2014 tv <tv> 1.8.0-3.mga5
+ Revision: 633629
- rebuild for new xserver RC

* Fri Jun 06 2014 tv <tv> 1.8.0-2.mga5
+ Revision: 633615
- rebuild for new xserver RC

* Tue May 13 2014 tv <tv> 1.8.0-1.mga5
+ Revision: 622425
- new release

* Wed Apr 30 2014 tv <tv> 1.7.99.2-2.mga5
+ Revision: 618940
- build for x.org 1.16

* Wed Apr 30 2014 tv <tv> 1.7.99.2-1.mga5
+ Revision: 618935
- new release

* Tue Apr 15 2014 tv <tv> 1.7.99.1-2.mga5
+ Revision: 614301
- rebuild for new xserver

* Tue Apr 01 2014 tv <tv> 1.7.99.1-1.mga5
+ Revision: 611182
- pkgconfig(libevdev)
- new pre-release

* Wed Mar 19 2014 tv <tv> 1.7.4-1.mga5
+ Revision: 605910
- new release

* Tue Feb 04 2014 tv <tv> 1.7.3-1.mga5
+ Revision: 582214
- new release

* Sat Oct 19 2013 umeabot <umeabot> 1.7.1-3.mga4
+ Revision: 525369
- Mageia 4 Mass Rebuild

* Thu May 30 2013 tv <tv> 1.7.1-2.mga4
+ Revision: 433098
- submit to core/release

* Fri May 24 2013 tv <tv> 1.7.1-1.mga4
+ Revision: 425747
- adjust file list
- rediff patch
- new release

* Sat Feb 02 2013 tv <tv> 1.6.3-1.mga3
+ Revision: 394084
- new release

* Mon Jan 14 2013 umeabot <umeabot> 1.6.2-3.mga3
+ Revision: 385964
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 06 2012 tv <tv> 1.6.2-2.mga3
+ Revision: 288928
- rebuild for new xserver

* Wed Jun 13 2012 tv <tv> 1.6.2-1.mga3
+ Revision: 260360
- new release

* Wed Jun 06 2012 tmb <tmb> 1.6.1-3.mga3
+ Revision: 256346
- rebuild for core/release

* Fri Jun 01 2012 tv <tv> 1.6.1-2.mga3
+ Revision: 252987
- rebuild b/c of ia32 failure

* Thu May 31 2012 tv <tv> 1.6.1-1.mga3
+ Revision: 252063
- BR mtdev-devel
- rediff patches
- new release

* Tue Dec 06 2011 tmb <tmb> 1.5.0-4.mga2
+ Revision: 177441
- submit to core/release

* Sat Oct 08 2011 tv <tv> 1.5.0-3.mga2
+ Revision: 153297
- really rebuild for xserver-1.11

* Sat Oct 08 2011 colin <colin> 1.5.0-2.mga2
+ Revision: 153027
- Rebuild for new x11-server

* Wed Sep 07 2011 tv <tv> 1.5.0-1.mga2
+ Revision: 140349
- new release

* Wed Jun 29 2011 tv <tv> 1.4.1-1.mga2
+ Revision: 116130
- new release
- add URL to source0

* Fri Mar 04 2011 tv <tv> 1.4.0-2.mga1
+ Revision: 64381
- rebuild for new xserver-1.10

* Fri Mar 04 2011 tv <tv> 1.4.0-1.mga1
+ Revision: 63990
- new release

* Thu Jan 13 2011 colin <colin> 1.3.0-5.mga1
+ Revision: 16490
- imported package x11-driver-input-synaptics

